@@ -65,19 +65,15 @@ test_that(
     "https://s3-us-west-2.amazonaws.com/mrlc/PR_landcover_wimperv_10-28-08_se5.zip" %>%
       httr::GET(httr::progress(), httr::write_disk(raw_zip, overwrite = TRUE))
     unzip(raw_zip, exdir = raw_tmp)
-    raw <- terra::rast(paste0(raw_tmp, "/pr_landcover_wimperv_10-28-08_se5.img"))
+    raw <- terra::rast(file.path(raw_tmp, "pr_landcover_wimperv_10-28-08_se5.img"))
     feddata <-
       FedData::get_nlcd(
         template = raw,
-        label = "PR",
+        label = basename(tempfile()),
         year = 2001,
-        landmass = "PR",
-        force.redo = TRUE
+        landmass = "PR"
       )
 
-    raw %<>%
-      raster::raster()
-
     expect_true(
       all((feddata - raw)[] == 0, na.rm = TRUE)
     )
